@@ -3,6 +3,6 @@ from django.conf.urls import url
 from alipay.views import AlipayCallbackView, AlipayRedirectView
 
 urlpatterns = [
-    url('^redirect/(?P<pk>.*?)/$', AlipayRedirectView.as_view(), name='alipay_redirect'),
+    url('^redirect/(?P<out_no>.*?)/$', AlipayRedirectView.as_view(), name='alipay_redirect'),
     url('^callback/$', AlipayCallbackView.as_view(), name='alipay_callback'),
 ]
