@@ -12,7 +12,6 @@ urlpatterns = [
     ]
 """
 
-import user_agents
 from django.http import HttpResponse, HttpResponseServerError
 from django.shortcuts import get_object_or_404, redirect, render
 from django.urls import reverse
@@ -20,8 +19,7 @@ from django.utils.decorators import method_decorator
 from django.views import View
 from django.views.decorators.csrf import csrf_exempt
 
-from alipay.helpers import get_alipay_api
-from alipay.models import AlipayPayment
+from alipay.models import AlipayPayment, Provider
 
 
 class AlipayRedirectView(View):
@@ -29,9 +27,6 @@ class AlipayRedirectView(View):
     他人生成AlipayPayment以后，跳转到本view就能重定向到alipay，继续完成支付流程
     样例见： example_alipay_create_view
     """
-    UA_WEB = 'web'  # web直接到账
-    UA_WAP = 'wap'  # 手机支付
-    UA_AUTO = 'auto'  # 根据UA来决定用WAP还是WEB
 
     def handle_redirect(self, redirect_url):
         """ 得到alipay支付地址以后，定义如何跳转（默认为直接跳转，可以自己改成打开loading页面，用JS跳转 """
@@ -42,35 +37,14 @@ class AlipayRedirectView(View):
         return request.build_absolute_uri(reverse('alipay_callback'))
 
     def get(self, request, out_no):
-        ua_mode = request.GET.get('ua', self.UA_WEB)  # 默认用web模式，因为WAP的需要另外申请，不自动开通
-
         payment = get_object_or_404(AlipayPayment, out_no=out_no)
-        alipay_api = get_alipay_api(payment.seller_email)
-        if not payment.seller_email:
-            payment.seller_email = alipay_api.seller_email
-            payment.save()
-
-        if ua_mode == self.UA_AUTO:
-            ua = user_agents.parse(request.META['HTTP_USER_AGENT'])
-            if ua.is_pc:
-                ua_mode = self.UA_WEB
-            else:
-                ua_mode = self.UA_WAP
-
-        assert ua_mode in [self.UA_WEB, self.UA_WAP]
-        if ua_mode == self.UA_WEB:
-            create_pay_url = alipay_api.client.create_direct_pay_url
-        else:
-            create_pay_url = alipay_api.client.create_wap_pay_url
-
-        pay_url = create_pay_url(
-            payment.out_no,
-            payment.subject,
-            payment.body,
-            "{:.2f}".format(payment.amount_total),
+        client = payment.provider.get_client()
+        pay_url = client.create_pay_url(
+            out_trade_no=payment.out_no,
+            subject=payment.subject,
+            total_amount="{:.2f}".format(payment.amount_total),
             notify_url=self.get_callback_url(request, payment, is_notify=True),
             return_url=self.get_callback_url(request, payment, is_notify=False),
-            expire=payment.expire,
         )
         return self.handle_redirect(pay_url)
 
@@ -111,11 +85,15 @@ class AlipayCallbackView(View):
     def handle_alipay_callback(cls, data):
         result = None
         try:
-            # seller_email = data['seller_email']  # seller email 可能带码
-            pid = data['seller_id']
-            alipay_api = get_alipay_api(pid=pid)
-            result = alipay_api.client.get_verified_result(data)
-            assert result.is_success != 'F', 'payment failed'
+            app_id = data['app_id']
+            provider = Provider.objects.get(app_id=app_id)
+
+            client = provider.get_client()
+            result = client.get_verified_result(data)
+
+            # alipay return has no trade_status, 一律认为成功
+            if result.trade_status is None:
+                result.trade_status = AlipayPayment.TRADE_SUCCESS
 
             payment = AlipayPayment.objects.get(out_no=result.out_trade_no)
 
